<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>Leader</name>
    <message>
        <location filename="../Leader.js" line="+60"/>
        <source>Arrow position</source>
        <translation>箭头位置</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Next vertex</source>
        <translation>下一顶点</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <location filename="../Leader.ui" line="+23"/>
        <source>Undo Last Segement</source>
        <translation>取消上一步</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Arrow head</source>
        <translation>箭头头部</translation>
    </message>
    <message>
        <location filename="../LeaderInit.js" line="+2"/>
        <source>&amp;Leader</source>
        <translation>引线(&amp;L)</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw leader (line sequence with arrow)</source>
        <translation>引线标注(箭头后面跟着指引线)</translation>
    </message>
</context>
</TS>
